# ACGC

## Overview
The acgc package is a collection of data analysis functions used by the Atmospheric Chemistry and Global Change Research Group (ACGC). Programs are written in Python 3.

## Installation

For conda users:

 `conda install -c conda-forge acgc`

For pip users:

 `pip install acgc`

#### For developers
If you plan to modify or improve the acgc package, an editable installation may be better:
`pip install -e git+https://github.com/cdholmes/acgc-python`
Your local files can then be managed with git, including keeping up-to-date with the github source repository (e.g. `git pull`).

#### Classic version
The old version of this package (before conversion to an importable python module) is accessible as the "classic" branch of this repository on github.

## Documentation

See https://cdholmes.github.io/acgc-python

## Demos
The [`demo`](./demo/) folder contains examples of how to accomplish common data analysis and visualization tasks, including using many of the functions within the `acgc` library.

